# myapp/appOnly/__init__.py

# from myApp.myApp import main
# from myApp.myApp.main import set_false_string
#
# __all__ = ['set_false_string', 'main']



# Configs

# CONFIG = {
#     'debug': False
# }
#
# print("myapp package initialized")
